/**
 * Copyright (c) 2000-2009, Jasig, Inc.
 * See license distributed with this file and available online at
 * https://www.ja-sig.org/svn/jasig-parent/tags/rel-10/license-header.txt
 */

package org.jasig.portal.rendering;

import java.util.LinkedList;
import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.stream.XMLEventReader;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.events.XMLEvent;

import org.jasig.portal.utils.cache.CacheKey;
import org.jasig.portal.xml.XmlUtilities;
import org.jasig.portal.xml.XmlUtilitiesImpl;
import org.jasig.portal.xml.stream.FilteringXMLEventReader;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

/**
 * Logs the StAX events
 * 
 * @author Eric Dalquist
 * @version $Revision: 22031 $
 */
public class LoggingStAXComponent extends StAXPipelineComponentWrapper {
    private Logger logger = LoggerFactory.getLogger(getClass());
    
    private XmlUtilities xmlUtilities;
    private boolean logFullDocument = true;
    private boolean logEvents = true;
    private boolean logFullDocumentAsHtml = false;

    public void setLoggerName(String loggerName) {
        logger = LoggerFactory.getLogger(loggerName);
    }
    public void setLogFullDocument(boolean logFullDocument) {
        this.logFullDocument = logFullDocument;
    }
    public void setLogFullDocumentAsHtml(boolean logFullDocumentAsHtml) {
        this.logFullDocumentAsHtml = logFullDocumentAsHtml;
    }
    public void setLogEvents(boolean logEvents) {
        this.logEvents = logEvents;
    }
    
    @Autowired
    public void setXmlUtilities(XmlUtilities xmlUtilities) {
        this.xmlUtilities = xmlUtilities;
    }
    
    @Override
    public CacheKey getCacheKey(HttpServletRequest request, HttpServletResponse response) {
        return this.wrappedComponent.getCacheKey(request, response);
    }
    
    @Override
    public PipelineEventReader<XMLEventReader, XMLEvent> getEventReader(HttpServletRequest request, HttpServletResponse response) {
        final PipelineEventReader<XMLEventReader, XMLEvent> pipelineEventReader = this.wrappedComponent.getEventReader(request, response);
        
        final XMLEventReader eventReader = pipelineEventReader.getEventReader();
        final LoggingXMLEventReader loggingEventReader = new LoggingXMLEventReader(eventReader);
        
        return new PipelineEventReaderImpl<XMLEventReader, XMLEvent>(loggingEventReader);
    }
    
    private class LoggingXMLEventReader extends FilteringXMLEventReader {
        private final List<XMLEvent> eventBuffer = new LinkedList<XMLEvent>();
        
        public LoggingXMLEventReader(XMLEventReader reader) {
            super(reader);
        }

        @Override
        protected XMLEvent filterEvent(XMLEvent event, boolean peek) {
            if (logEvents && logger.isDebugEnabled()) {
                if (peek) {
                    logger.debug("Peek: " + XmlUtilitiesImpl.toString(event));
                }
                else {
                    logger.debug("Read: " + XmlUtilitiesImpl.toString(event));
                }
            }
            
            if (!peek && logFullDocument && logger.isDebugEnabled()) {
                eventBuffer.add(event);
                
                if (event.isEndDocument()) {
                    final String xmlOutput = xmlUtilities.serializeXMLEvents(eventBuffer, logFullDocumentAsHtml);
                    logger.debug("\n" + xmlOutput);
                }
            }
            
            return event;
        }

        @Override
        public void close() throws XMLStreamException {
            this.eventBuffer.clear();
        }
    }
}
