/**
 * Copyright 2007 The JA-SIG Collaborative.  All rights reserved.
 * See license distributed with this file and
 * available online at http://www.uportal.org/license.html
 */
package org.jasig.portal.rendering.xslt;

import java.util.Map;
import java.util.Properties;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.xml.transform.Transformer;

import org.jasig.portal.utils.cache.CacheKey;

/**
 * Used by a {@link XSLTComponent} to configure the {@link Transformer}
 * 
 * @author Eric Dalquist
 * @version $Revision: 21801 $
 */
public interface TransformerConfigurationSource {
    /**
     * Passed on to {@link Transformer#setParameter(String, Object)}, ignored if null is returned
     */
    public Map<String, Object> getParameters(HttpServletRequest request, HttpServletResponse response);
    
    /**
     * Passed on to {@link Transformer#setOutputProperties(Properties)}, ignored if null is returned
     */
    public Properties getOutputProperties(HttpServletRequest request, HttpServletResponse response);
    
    /**
     * A key representing the state of the parameters and properties for the request, ignored if null is returned
     */
    public CacheKey getCacheKey(HttpServletRequest request, HttpServletResponse response);
}
