package org.jasig.portal.spring.spel;

import org.springframework.binding.expression.spel.SpringELExpressionParser;
import org.springframework.expression.Expression;
import org.springframework.expression.ParseException;
import org.springframework.web.context.request.WebRequest;

/**
 * IPortalSpELService provides an interface for parsing strings using the
 * Spring expression language.  Strings are assumed to be a potential mixture
 * of SpEL expressions contained inside a ${ } and text string content.  For 
 * example, a portal-relative URL path might be formatted as 
 * ${request.contextPath}/my/path.
 * 
 * @author Jen Bourey, jbourey@unicon.net
 * @version $Revision: 21553 $
 */
public interface IPortalSpELService {
    
    /**
     * @see SpringELExpressionParser#parseExpression(String, org.springframework.binding.expression.ParserContext)
     */
    public Expression parseExpression(String expressionString) throws ParseException;

    /**
     * Parse the supplied string by replacing any ${ } blocks with the 
     * SpEL-evaluated value.
     * 
     * @param string  string to be evaluated
     * @param request request (may be either a portlet or servlet request)
     * @return        evaluated string
     */
    public String parseString(String string, WebRequest request);
    
    /**
     * Evaluates the expression in the standard portal evaluation context
     * 
     * @see Expression#getValue(org.springframework.expression.EvaluationContext)
     */
    public Object getValue(Expression expression, WebRequest request);
    
    /**
     * @see #parseExpression(String)
     * @see #getValue(Expression, WebRequest)
     */
    public Object getValue(String expressionString, WebRequest request);
    
    /**
     * Evaluates the expression in the standard portal evaluation context
     * 
     * @see Expression#getValue(org.springframework.expression.EvaluationContext, Class)
     */
    public <T> T getValue(Expression expression, WebRequest request, Class<T> desiredResultType);
    
    /**
     * @see #parseExpression(String)
     * @see #getValue(Expression, WebRequest, Class)
     */
    public <T> T getValue(String expressionString, WebRequest request, Class<T> desiredResultType);
}
