/**
 * Copyright (c) 2000-2010, Jasig, Inc.
 * See license distributed with this file and available online at
 * https://www.ja-sig.org/svn/jasig-parent/tags/rel-10/license-header.txt
 */

package org.jasig.portal.xml.stream;

import java.util.LinkedHashMap;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;

import javax.xml.namespace.NamespaceContext;
import javax.xml.stream.XMLEventReader;
import javax.xml.stream.XMLEventWriter;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.events.XMLEvent;

/**
 * Caches events written to a List
 * 
 * @author Eric Dalquist
 * @version $Revision: 21873 $
 */
public class XMLEventBufferWriter implements XMLEventWriter {
    private final Map<String, String> prefixes = new LinkedHashMap<String, String>();
    private final List<XMLEvent> eventBuffer = new LinkedList<XMLEvent>();
    private NamespaceContext namespaceContext;
    private String defaultNamespace;
    
    /**
     * @return The buffer of events written to the writer so far
     */
    public List<XMLEvent> getEventBuffer() {
        return this.eventBuffer;
    }
    
    /**
     * @return Prefixes configured via {@link #setPrefix(String, String)}
     */
    public Map<String, String> getPrefixes() {
        return this.prefixes;
    }

    /**
     * @return The default namespace specified by {@link #setDefaultNamespace(String)}
     */
    public String getDefaultNamespace() {
        return this.defaultNamespace;
    }


    @Override
    public void flush() throws XMLStreamException {
    }

    @Override
    public void close() throws XMLStreamException {
    }

    @Override
    public void add(XMLEvent event) throws XMLStreamException {
        this.eventBuffer.add(event);
    }

    @Override
    public void add(XMLEventReader reader) throws XMLStreamException {
        while (reader.hasNext()) {
            this.eventBuffer.add(reader.nextEvent());
        }
    }

    @Override
    public String getPrefix(String uri) throws XMLStreamException {
        return prefixes.get(uri);
    }

    @Override
    public void setPrefix(String prefix, String uri) throws XMLStreamException {
        this.prefixes.put(uri, prefix);
    }

    @Override
    public void setDefaultNamespace(String uri) throws XMLStreamException {
        this.defaultNamespace = uri;
    }

    @Override
    public void setNamespaceContext(NamespaceContext context) throws XMLStreamException {
        this.namespaceContext = context;
    }

    @Override
    public NamespaceContext getNamespaceContext() {
        return this.namespaceContext;
    }
}